// Copyright 2020, Collabora, Ltd.
// SPDX-License-Identifier: BSL-1.0
/*!
 * @file
 * @brief  EGL API wrapper header.
 * @author Rylie Pavlik <rylie.pavlik@collabora.com>
 * @ingroup aux_ogl
 */

#pragma once

#include "glad/egl.h" // IWYU pragma: export
